package com.hai.service.impl;

import com.hai.common.utils.MD5Util;
import com.hai.dao.HighMerchantMapper;
import com.hai.entity.HighMerchant;
import com.hai.entity.HighMerchantExample;
import com.hai.entity.SecUser;
import com.hai.service.HighMerchantService;
import com.hai.service.SecUserService;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Service("highMerchantService")
public class HighMerchantServiceImpl implements HighMerchantService {

    @Resource
    private HighMerchantMapper highMerchantMapper;

    @Resource
    private SecUserService secUserService;

    @Override
    @Transactional
    public void editMerchant(HighMerchant highMerchant) throws Exception {
        if (highMerchant.getId() == null) {
            highMerchantMapper.insert(highMerchant);

            highMerchant.getSecUser().setUserName(highMerchant.getMerchantName());
            highMerchant.getSecUser().setLoginName(highMerchant.getSecUser().getTelephone());
            highMerchant.getSecUser().setPassword(MD5Util.encode(highMerchant.getSecUser().getPassword().getBytes()));
            highMerchant.getSecUser().setStatus(1);
            highMerchant.getSecUser().setRoleId(2L);
            highMerchant.getSecUser().setObjectType(2);
            highMerchant.getSecUser().setObjectId(highMerchant.getId());
            highMerchant.getSecUser().setCreateTime(new Date());
            highMerchant.getSecUser().setUpdateTime(new Date());
            secUserService.addUser(highMerchant.getSecUser());

        } else {
            highMerchantMapper.updateByPrimaryKey(highMerchant);
        }
    }

    @Override
    public HighMerchant getMerchantById(Long id) {
        return highMerchantMapper.selectByPrimaryKey(id);
    }

    @Override
    public List<HighMerchant> getMerchantList(Map<String, Object> map) {
        HighMerchantExample example = new HighMerchantExample();
        HighMerchantExample.Criteria criteria = example.createCriteria();

        if (MapUtils.getLong(map, "companyId") != null) {
            criteria.andCompanyIdEqualTo(MapUtils.getLongValue(map, "companyId"));
        }

        if (MapUtils.getLong(map, "merchantKey") != null) {
            criteria.andMerchantKeyEqualTo(MapUtils.getString(map, "merchantKey"));
        }

        if (StringUtils.isNotBlank(MapUtils.getString(map, "merchantName"))) {
            criteria.andMerchantNameLike("%" + MapUtils.getString(map, "merchantName") + "%");
        }

        if (StringUtils.isNotBlank(MapUtils.getString(map, "telephone"))) {
            criteria.andTelephoneEqualTo(MapUtils.getString(map, "telephone"));
        }

        example.setOrderByClause("create_time desc");
        return highMerchantMapper.selectByExample(example);
    }
}
